==> teamnoob_warp-0.1.4.tar.gz: teamnoob_warp-0.1.4/README.md <==
# TN WARP

![Logo](https://drive.google.com/file/d/1HxOOjmbzY6E00di8FRq3eLjW_PuPLQu5/view?usp=drivesdk)

## Overview

**TN WARP** is a Python library designed to automate sending WARP MB using a referrer. It leverages the Cloudflare API to make this process efficient and easy to use.

## Features

- Automates sending WARP MB
- User-friendly Python API
- Stylish terminal output with `cfonts`
- Simple to set up and use

## Installation

To install TN WARP, use `pip`:

```bash
pip install TeamNoob-WARP
```

## Usage

### Python API

To use TN WARP in your Python code, follow these steps:

1. Import the `tnwarp` function from the `TeamNoob-WARP` package.
2. Call the `tnwarp` function with the required argument.

Here's an example:

```python
from TeamNoob_WARP import tnwarp

# Execute TN WARP with 'rohit' as the argument
tnwarp("rohit")
```

### Command Line Interface

If you want to run TN WARP from the command line, you can execute:

```bash
tnwarp rohit
```

## Requirements

- Python 3.6 or higher
- `requests`
- `python-cfonts`

These dependencies will be installed automatically when you install TN WARP using `pip`.

## License

This project does not specify a license. You may use the code as needed, and contributions are appreciated.

## Contact

For questions or support, contact:

- **Author**: GW ROHIT
- **Email**: teamnoob909@gmail.com
- **Telegram**: [Team Noob](https://t.me/TeamNoob_Official)

## Disclaimer

This tool is provided "as is" without warranties. The authors are not responsible for any issues or damages arising from the use of this tool.

---

**TN WARP** © 2024 by Team Noob. All rights reserved.

==> teamnoob_warp-0.1.5.tar.gz: teamnoob_warp-0.1.5/README.md <==
# TN WARP

![Logo](http://birthday-wish-from-rohit.000.pe/TN.jpg)

## Overview

**TN WARP** is a Python library designed to automate sending WARP MB using a referrer. It leverages the Cloudflare API to make this process efficient and easy to use.

## Features

- Automates sending WARP MB
- User-friendly Python API
- Stylish terminal output with `cfonts`
- Simple to set up and use

## Installation

To install TN WARP, use `pip`:

```bash
pip install TeamNoob-WARP
```

### Python API

To use TN WARP in your Python code, follow these steps:

1. Import the `tnwarp` function from the `TeamNoob_WARP` package.
2. Call the `tnwarp` function with the required argument.

Here's an example:

```python
from TeamNoob_WARP import tnwarp

# Execute TN WARP with 'rohit' as the argument
tnwarp("rohit")
```

### Command Line Interface

If you want to run TN WARP from the command line, you can execute:

```bash
tnwarp rohit
```

## Requirements

- Python 3.6 or higher
- `requests`
- `python-cfonts`

These dependencies will be installed automatically when you install TN WARP using `pip`.

## License

This project does not specify a license. You may use the code as needed, and contributions are appreciated.

## Contact

For questions or support, contact:

- **Author**: GW ROHIT
- **Email**: teamnoob909@gmail.com
- **Telegram**: [Team Noob](https://t.me/TeamNoob_Official)

## Disclaimer

This tool is provided "as is" without warranties. The authors are not responsible for any issues or damages arising from the use of this tool.

---

**TN WARP** © 2024 by Team Noob. All rights reserved.
